@@ -9,8 +9,8 @@ use Types::Standard qw[ Optional Bool StrMatch Undef Int ];
 use Types::PDL -types;
 use Type::Params qw[ compile_named ];
 
-use Carp;
-use PDL::Lite;
+use Carp ();
+use PDL::Lite ();
 
 use Hash::Wrap ( { -class => __PACKAGE__ . '::bin_on_index' } );
 
